# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
# implied.
# See the License for the specific language governing permissions and
# limitations under the License.

class RemotePolicyError(Exception):
    """Base exception for remote policy errors."""
    pass

class RemotePolicyServerError(RemotePolicyError):
    """Exception raised when the remote policy server returns an error."""
    pass

class RemotePolicyTimeoutError(RemotePolicyError):
    """Exception raised when the remote policy server request times out."""
    pass

class RemotePolicyConfigError(RemotePolicyError):
    """Exception raised when there is a configuration error."""
    pass 


class PolicyNotAuthorized(Exception):
    """Default exception raised for policy enforcement failure."""

    pass


class InvalidScope(Exception):
    """Raised when the scope of the request mismatches the policy scope."""
    pass
